/* Generated by wayland-scanner 1.25.0 */

#ifndef EXT_BACKGROUND_EFFECT_V1_ENUM_PROTOCOL_H
#define EXT_BACKGROUND_EFFECT_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef EXT_BACKGROUND_EFFECT_MANAGER_V1_ERROR_ENUM
#define EXT_BACKGROUND_EFFECT_MANAGER_V1_ERROR_ENUM
enum ext_background_effect_manager_v1_error {
	/**
	 * the surface already has a background effect object
	 */
	EXT_BACKGROUND_EFFECT_MANAGER_V1_ERROR_BACKGROUND_EFFECT_EXISTS = 0,
};
#endif /* EXT_BACKGROUND_EFFECT_MANAGER_V1_ERROR_ENUM */

#ifndef EXT_BACKGROUND_EFFECT_MANAGER_V1_CAPABILITY_ENUM
#define EXT_BACKGROUND_EFFECT_MANAGER_V1_CAPABILITY_ENUM
enum ext_background_effect_manager_v1_capability {
	/**
	 * the compositor supports applying blur
	 */
	EXT_BACKGROUND_EFFECT_MANAGER_V1_CAPABILITY_BLUR = 1,
};
#endif /* EXT_BACKGROUND_EFFECT_MANAGER_V1_CAPABILITY_ENUM */

#ifndef EXT_BACKGROUND_EFFECT_SURFACE_V1_ERROR_ENUM
#define EXT_BACKGROUND_EFFECT_SURFACE_V1_ERROR_ENUM
enum ext_background_effect_surface_v1_error {
	/**
	 * the associated surface has been destroyed
	 */
	EXT_BACKGROUND_EFFECT_SURFACE_V1_ERROR_SURFACE_DESTROYED = 0,
};
#endif /* EXT_BACKGROUND_EFFECT_SURFACE_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
