/* Generated by wayland-scanner 1.25.0 */

#ifndef KEYBOARD_FILTER_EXPERIMENTAL_V1_ENUM_PROTOCOL_H
#define KEYBOARD_FILTER_EXPERIMENTAL_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef XX_KEYBOARD_FILTER_V1_ERROR_ENUM
#define XX_KEYBOARD_FILTER_V1_ERROR_ENUM
enum xx_keyboard_filter_v1_error {
	/**
	 * compositor received serial not adhering to requirements
	 */
	XX_KEYBOARD_FILTER_V1_ERROR_INVALID_SERIAL = 0x1,
};
#endif /* XX_KEYBOARD_FILTER_V1_ERROR_ENUM */

#ifndef XX_KEYBOARD_FILTER_V1_FILTER_ACTION_ENUM
#define XX_KEYBOARD_FILTER_V1_FILTER_ACTION_ENUM
enum xx_keyboard_filter_v1_filter_action {
	/**
	 * consume the key event
	 */
	XX_KEYBOARD_FILTER_V1_FILTER_ACTION_CONSUME = 0,
	/**
	 * pass the key event to the text input client
	 */
	XX_KEYBOARD_FILTER_V1_FILTER_ACTION_PASSTHROUGH = 1,
};
#endif /* XX_KEYBOARD_FILTER_V1_FILTER_ACTION_ENUM */

#ifndef XX_KEYBOARD_FILTER_MANAGER_V1_ERROR_ENUM
#define XX_KEYBOARD_FILTER_MANAGER_V1_ERROR_ENUM
enum xx_keyboard_filter_manager_v1_error {
	/**
	 * an argument is already bound
	 */
	XX_KEYBOARD_FILTER_MANAGER_V1_ERROR_ALREADY_BOUND = 0x1,
	/**
	 * the keyboard i attached to the wrong seat for this operation
	 */
	XX_KEYBOARD_FILTER_MANAGER_V1_ERROR_WRONG_SEAT = 0x2,
};
#endif /* XX_KEYBOARD_FILTER_MANAGER_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
