/* Generated by wayland-scanner 1.25.0 */

#ifndef COMMIT_TIMING_V1_ENUM_PROTOCOL_H
#define COMMIT_TIMING_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef WP_COMMIT_TIMING_MANAGER_V1_ERROR_ENUM
#define WP_COMMIT_TIMING_MANAGER_V1_ERROR_ENUM
enum wp_commit_timing_manager_v1_error {
	/**
	 * commit timer already exists for surface
	 */
	WP_COMMIT_TIMING_MANAGER_V1_ERROR_COMMIT_TIMER_EXISTS = 0,
};
#endif /* WP_COMMIT_TIMING_MANAGER_V1_ERROR_ENUM */

#ifndef WP_COMMIT_TIMER_V1_ERROR_ENUM
#define WP_COMMIT_TIMER_V1_ERROR_ENUM
enum wp_commit_timer_v1_error {
	/**
	 * timestamp contains an invalid value
	 */
	WP_COMMIT_TIMER_V1_ERROR_INVALID_TIMESTAMP = 0,
	/**
	 * timestamp exists
	 */
	WP_COMMIT_TIMER_V1_ERROR_TIMESTAMP_EXISTS = 1,
	/**
	 * the associated surface no longer exists
	 */
	WP_COMMIT_TIMER_V1_ERROR_SURFACE_DESTROYED = 2,
};
#endif /* WP_COMMIT_TIMER_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
