/* Generated by wayland-scanner 1.25.0 */

#ifndef CURSOR_SHAPE_V1_ENUM_PROTOCOL_H
#define CURSOR_SHAPE_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_ENUM
#define WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_ENUM
/**
 * @ingroup iface_wp_cursor_shape_device_v1
 * cursor shapes
 *
 * This enum describes cursor shapes.
 *
 * The names are taken from the CSS W3C specification:
 * https://w3c.github.io/csswg-drafts/css-ui/#cursor
 * with a few additions.
 *
 * Note that there are some groups of cursor shapes that are related:
 * The first group is drag-and-drop cursors which are used to indicate
 * the selected action during dnd operations. The second group is resize
 * cursors which are used to indicate resizing and moving possibilities
 * on window borders. It is recommended that the shapes in these groups
 * should use visually compatible images and metaphors.
 */
enum wp_cursor_shape_device_v1_shape {
	/**
	 * default cursor
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_DEFAULT = 1,
	/**
	 * a context menu is available for the object under the cursor
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_CONTEXT_MENU = 2,
	/**
	 * help is available for the object under the cursor
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_HELP = 3,
	/**
	 * pointer that indicates a link or another interactive element
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_POINTER = 4,
	/**
	 * progress indicator
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_PROGRESS = 5,
	/**
	 * program is busy, user should wait
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_WAIT = 6,
	/**
	 * a cell or set of cells may be selected
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_CELL = 7,
	/**
	 * simple crosshair
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_CROSSHAIR = 8,
	/**
	 * text may be selected
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_TEXT = 9,
	/**
	 * vertical text may be selected
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_VERTICAL_TEXT = 10,
	/**
	 * drag-and-drop: alias of/shortcut to something is to be created
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_ALIAS = 11,
	/**
	 * drag-and-drop: something is to be copied
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_COPY = 12,
	/**
	 * drag-and-drop: something is to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_MOVE = 13,
	/**
	 * drag-and-drop: the dragged item cannot be dropped at the current cursor location
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_NO_DROP = 14,
	/**
	 * drag-and-drop: the requested action will not be carried out
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_NOT_ALLOWED = 15,
	/**
	 * drag-and-drop: something can be grabbed
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_GRAB = 16,
	/**
	 * drag-and-drop: something is being grabbed
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_GRABBING = 17,
	/**
	 * resizing: the east border is to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_E_RESIZE = 18,
	/**
	 * resizing: the north border is to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_N_RESIZE = 19,
	/**
	 * resizing: the north-east corner is to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_NE_RESIZE = 20,
	/**
	 * resizing: the north-west corner is to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_NW_RESIZE = 21,
	/**
	 * resizing: the south border is to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_S_RESIZE = 22,
	/**
	 * resizing: the south-east corner is to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_SE_RESIZE = 23,
	/**
	 * resizing: the south-west corner is to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_SW_RESIZE = 24,
	/**
	 * resizing: the west border is to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_W_RESIZE = 25,
	/**
	 * resizing: the east and west borders are to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_EW_RESIZE = 26,
	/**
	 * resizing: the north and south borders are to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_NS_RESIZE = 27,
	/**
	 * resizing: the north-east and south-west corners are to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_NESW_RESIZE = 28,
	/**
	 * resizing: the north-west and south-east corners are to be moved
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_NWSE_RESIZE = 29,
	/**
	 * resizing: that the item/column can be resized horizontally
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_COL_RESIZE = 30,
	/**
	 * resizing: that the item/row can be resized vertically
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_ROW_RESIZE = 31,
	/**
	 * something can be scrolled in any direction
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_ALL_SCROLL = 32,
	/**
	 * something can be zoomed in
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_ZOOM_IN = 33,
	/**
	 * something can be zoomed out
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_ZOOM_OUT = 34,
	/**
	 * drag-and-drop: the user will select which action will be carried out (non-css value)
	 * @since 2
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_DND_ASK = 35,
	/**
	 * resizing: something can be moved or resized in any direction (non-css value)
	 * @since 2
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_ALL_RESIZE = 36,
};
/**
 * @ingroup iface_wp_cursor_shape_device_v1
 */
#define WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_DND_ASK_SINCE_VERSION 2
/**
 * @ingroup iface_wp_cursor_shape_device_v1
 */
#define WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_ALL_RESIZE_SINCE_VERSION 2
#endif /* WP_CURSOR_SHAPE_DEVICE_V1_SHAPE_ENUM */

#ifndef WP_CURSOR_SHAPE_DEVICE_V1_ERROR_ENUM
#define WP_CURSOR_SHAPE_DEVICE_V1_ERROR_ENUM
enum wp_cursor_shape_device_v1_error {
	/**
	 * the specified shape value is invalid
	 */
	WP_CURSOR_SHAPE_DEVICE_V1_ERROR_INVALID_SHAPE = 1,
};
#endif /* WP_CURSOR_SHAPE_DEVICE_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
